Learn R Programming

wccsom (version 1.2.11)

wccassign: Assign patterns to nodes in a SOM network by WCC value

Description

KNN assignment of patterns to units in a Kohonen map, with maximal WCC as the criterion.

Usage

wccassign(x, data)

Arguments

x
Trained Kohonen map
data
Data matrix

Value

Returns a list with components:
classif
Unit numbers to which rows in the data matrix are assigned
wccs
wcc value of rows in the data matrix and the units to which they are assigned.

See Also

wccsom

Examples

Run this code
data(cepha)
gr <- somgrid(3,3, "hexagonal")
set.seed(7)
x <- wccsom(cepha$patterns, grid = gr, trwidth = 20, rlen = 50,
            FineTune = FALSE, keep.data = FALSE)
sombins <- wccassign(x, cepha$patterns)

Run the code above in your browser using DataLab