At this point, no facilities are implemented for growing networks or
k-means-like fine-tuning of the maps, such as in function wccsom.
wccxyf(data, Y, grid=somgrid(), rlen = 100, alpha = c(0.05, 0.01), radius = quantile(nhbrdist, 0.67), xweight = 0.5, trwidth = 20, toroidal = FALSE, keep.data = TRUE)rlen updates.rlen updates in
such a way that after one-third of the updates only the winning unit
is updated. The default is to start with a
value that covers 2/3 of all units.keep.data equals TRUE.keep.data equals TRUE.keep.data equals TRUE.SOM, plot.wccsom,
wccsom, wcc## Not run:
# data(degelder)
# gr <- somgrid(5, 5, "hexagonal")
# set.seed(7)
# x <- wccxyf(degelder$patterns, degelder$properties[,"cell.vol"],
# grid=gr, trwidth=20, rlen=100)
# ## End(Not run)
Run the code above in your browser using DataLab